( cd opt/kde/lib ; rm -rf libktorrent.so )
( cd opt/kde/lib ; ln -sf libktorrent.so.0.0.0 libktorrent.so )
( cd opt/kde/lib ; rm -rf libktorrent.so.0 )
( cd opt/kde/lib ; ln -sf libktorrent.so.0.0.0 libktorrent.so.0 )
